package com.ruoyi;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.core.util.ZipUtil;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;

import java.io.File;

@SpringBootTest
public class TestDownload {

    @Test
    public void Test() {
        try {
            // 压缩包的名称和路径
            String zipFilePath = "downloaded_files.zip";

            HttpResponse response = HttpUtil.createPost("https://10.12.48.78:8090/api/project/download/fd40de37-9c57-4597-8f74-d0754dfa17b2")
                    .execute();

            if (response.isOk()) {
                // 从响应头中获取文件名，这里假设Content-Disposition头包含文件名
                String contentDisposition = response.header("Content-Disposition");
                String fileName = extractFileNameFromContentDisposition(contentDisposition);

                if (StrUtil.isNotBlank(fileName)) {

                    // 保存下载的文件到临时位置
                    String tempFilePath = "temp_" + fileName;
                    FileUtil.writeBytes(IoUtil.readBytes(response.bodyStream()), FileUtil.file(tempFilePath));

                    System.out.println("文件下载成功：" + fileName);

                    // 将临时文件添加到压缩包中
//                    ZipUtil.addFile(zipFilePath, tempFilePath);

                    System.out.println("文件已添加到压缩包：" + zipFilePath);

                    // 删除临时文件
                    FileUtil.del(tempFilePath);
                } else {
                    System.err.println("无法从响应头中提取文件名");
                }
            } else {
                System.err.println("下载失败，状态码：" + response.getStatus());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 从Content-Disposition头中提取文件名。
     * 注意：这是一个简化的示例，真实场景可能需要更复杂的解析逻辑。
     *
     * @param contentDisposition Content-Disposition头的值
     * @return 提取的文件名，如果未找到则返回空字符串
     */
    private static String extractFileNameFromContentDisposition(String contentDisposition) {
        if (StrUtil.isBlank(contentDisposition)) {
            return "";
        }
        String[] parts = contentDisposition.split(";");
        for (String part : parts) {
            part = part.trim();
            if (part.startsWith("filename=")) {
                return part.substring(part.indexOf('=') + 1).replace("\"", "");
            }
        }
        return "";
    }
}
